@@ -9,9 +9,6 @@ class Social(AuthenticationBase):
         domain (str): Your auth0 domain (e.g: username.auth0.com)
     """
 
-    def __init__(self, domain):
-        self.domain = domain
-
     def login(self, client_id, access_token, connection, scope='openid'):
         """Login using a social provider's access token
 
@@ -21,7 +18,7 @@ class Social(AuthenticationBase):
         Facebook, Google, Twitter and Weibo.
 
         Args:
-            client_id (str): client name.
+            client_id (str): application's client id.
 
             access_token (str): social provider's access_token.
 
@@ -32,12 +29,11 @@ class Social(AuthenticationBase):
         """
 
         return self.post(
-            'https://%s/oauth/access_token' % self.domain,
+            'https://{}/oauth/access_token'.format(self.domain),
             data={
                 'client_id': client_id,
                 'access_token': access_token,
                 'connection': connection,
                 'scope': scope,
-            },
-            headers={'Content-Type': 'application/json'}
+            }
         )
